@@ -176,6 +176,7 @@ export const svgFilters = freeze([
   'feDiffuseLighting',
   'feDisplacementMap',
   'feDistantLight',
+  'feDropShadow',
   'feFlood',
   'feFuncA',
   'feFuncB',
@@ -203,7 +204,6 @@ export const svgDisallowed = freeze([
   'color-profile',
   'cursor',
   'discard',
-  'fedropshadow',
   'font-face',
   'font-face-format',
   'font-face-name',
@@ -254,6 +254,7 @@ export const mathMl = freeze([
   'mtr',
   'munder',
   'munderover',
+  'mprescripts',
 ]);
 
 // Similarly to SVG, we want to know all MathML elements,
