@@ -42,28 +42,29 @@ const customLaunchers = {
     browser: 'safari',
     os_version: 'Big Sur',
   },
-  bs_win81_ie_11: {
-    base: 'BrowserStack',
-    browser: 'ie',
-    browser_version: '11.0',
-    os: 'Windows',
-    os_version: '8.1',
-  },
-  bs_win10_edge_17: {
+  bs_monterey_safari_15: {
     base: 'BrowserStack',
     device: null,
-    os: 'Windows',
+    os: 'OS X',
+    browser_version: '15.6',
+    browser: 'safari',
+    os_version: 'Monterey',
+  },
+  bs_ventura_safari_16: {
+    base: 'BrowserStack',
+    device: null,
+    os: 'OS X',
+    browser_version: '16.5',
+    browser: 'safari',
+    os_version: 'Ventura',
+  },
+  bs_sonoma_safari_17: {
+    base: 'BrowserStack',
+    device: null,
+    os: 'OS X',
     browser_version: '17.0',
-    browser: 'edge',
-    os_version: '10',
-  },
-  bs_win10_edge_18: {
-    base: 'BrowserStack',
-    device: null,
-    os: 'Windows',
-    browser_version: '18.0',
-    browser: 'edge',
-    os_version: '10',
+    browser: 'safari',
+    os_version: 'Sonoma',
   },
   bs_win10_edge_84: {
     base: 'BrowserStack',
@@ -73,14 +74,6 @@ const customLaunchers = {
     browser: 'edge',
     os_version: '10',
   },
-  bs_win10_firefox_60: {
-    base: 'BrowserStack',
-    device: null,
-    os: 'Windows',
-    browser_version: '60.0',
-    browser: 'firefox',
-    os_version: '10',
-  },
   bs_win10_firefox_70: {
     base: 'BrowserStack',
     device: null,
@@ -113,6 +106,30 @@ const customLaunchers = {
     browser: 'firefox',
     os_version: '10',
   },
+  bs_win10_firefox_108: {
+    base: 'BrowserStack',
+    device: null,
+    os: 'Windows',
+    browser_version: '108.0',
+    browser: 'firefox',
+    os_version: '10',
+  },
+  bs_win10_firefox_120: {
+    base: 'BrowserStack',
+    device: null,
+    os: 'Windows',
+    browser_version: '120.0',
+    browser: 'firefox',
+    os_version: '11',
+  },
+  bs_win10_firefox_125: {
+    base: 'BrowserStack',
+    device: null,
+    os: 'Windows',
+    browser_version: '125.0',
+    browser: 'firefox',
+    os_version: '11',
+  },
   bs_win10_chrome_60: {
     base: 'BrowserStack',
     device: null,
@@ -153,6 +170,30 @@ const customLaunchers = {
     browser: 'chrome',
     os_version: '10',
   },
+  bs_win10_chrome_108: {
+    base: 'BrowserStack',
+    device: null,
+    os: 'Windows',
+    browser_version: '108.0',
+    browser: 'chrome',
+    os_version: '10',
+  },
+  bs_win10_chrome_120: {
+    base: 'BrowserStack',
+    device: null,
+    os: 'Windows',
+    browser_version: '120.0',
+    browser: 'chrome',
+    os_version: '11',
+  },
+  bs_win10_chrome_124: {
+    base: 'BrowserStack',
+    device: null,
+    os: 'Windows',
+    browser_version: '124.0',
+    browser: 'chrome',
+    os_version: '11',
+  },
 };
 
 const getAllBrowsers = () => Object.keys(customLaunchers);
@@ -160,12 +201,12 @@ const getRandomBrowser = () => sample(getAllBrowsers());
 
 /**
  * Environment variables are passed into the script and the depth of testing
- * is affected accordginly.
+ * is affected accordingly.
  *
  * - Whenever on a PR we only want to probe test with Firefox
  * - Whenever we are on the most recent node version on GitHub Actions we test via BrowserStack
  * - If none of the prior mentioned holds we assume to be running local and respect the passed
- *   in borwsers argv
+ *   in browsers argv
  */
 const shouldProbeOnly = argv.shouldProbeOnly === 'true';
 const shouldTestOnBrowserStack = argv.shouldTestOnBrowserStack === 'true';
