@@ -1,6 +1,6 @@
 import 'purify';
 import './test-suite';
-import tests from './fixtures/expect';
+import tests from './fixtures/expect.mjs';
 
 const xssTests = tests.filter(function (element) {
   if (/alert/.test(element.payload)) {
